@@ -75,7 +75,6 @@ struct group_item;
 #define Footer    3
 #define Title     4
 
-#ifndef HTADD
 extern int MenuServerOpened;
 
 /* These are all the colors one can use in HyperDoc. */
@@ -108,9 +107,6 @@ extern XFontStruct  *gActiveFont,
                     *gTtFont;
 
 
-#endif
-
-
 /** I am implementing a state node stack, this is the structure I store **/
 
 typedef struct state_node {
@@ -124,10 +120,8 @@ typedef struct state_node {
  struct state_node *next;
 } StateNode;
 
-#ifndef HTADD
 /** pointer to the top of the state node graph **/
 extern StateNode *top_state_node;
-#endif
 
 
 /* structure for a hyper text link */
@@ -401,7 +395,6 @@ extern HDWindow *gParentWindow;       /* the parent window. The one that
 extern HyperLink *quitLink; /** a special link to the protected quit page **/
 
 
-#ifndef HTADD
 /* From hyper.c */
 extern int      gXScreenNumber;
 extern Display *gXDisplay;
@@ -439,7 +432,6 @@ extern int need_scroll_up_button;
 extern int scrolling;
 extern int need_scroll_down_button;
 extern int space_width;
-#endif
 
 /* Here are some of the functions and constants declared and needed in
       htadd.c                                                    ******/
@@ -447,7 +439,6 @@ extern int space_width;
 #define NoChar   -9999
 #define temp_dir "/tmp/"
 #define db_file_name "ht.db"
-#define def_spad "/usr/local/fricas"
 
 
 /* Types of HyperDoc pages */
@@ -526,23 +517,12 @@ extern int space_width;
 
 /***      default fonts      ***/
 
-#if defined(RTplatform) || defined(PS2platform) || defined(RIOSplatform) || defined(AIX370platform)
-#define RmFontDefault         "Rom14"
-#define TtFontDefault         "Erg14"
-#define ActiveFontDefault     "Bld14"
-#define fricas_font_default      "Erg14"
-#define EmphasizeFontDefault  "Itl14"
-#define BoldFontDefault       "Bld14"
-#endif
-
-#if defined(SUNplatform) || defined (SUN4OS5platform) || defined(SGIplatform) || defined (HP9platform)  || defined(HP10platform) || defined (ALPHAplatform) || defined(LINUXplatform) || defined(MACOSXplatform) || defined(BSDplatform) || defined(CYGWINplatform)
 #define RmFontDefault         "-adobe-courier-medium-r-normal--18-*-*-*-m-*-iso8859-1"
 #define TtFontDefault         "-adobe-courier-medium-r-normal--18-*-*-*-m-*-iso8859-1"
 #define ActiveFontDefault     "-adobe-courier-bold-r-normal--18-*-*-*-m-*-iso8859-1"
 #define fricas_font_default      "-adobe-courier-bold-o-normal--18-*-*-*-m-*-iso8859-1"
 #define EmphasizeFontDefault  "-adobe-courier-medium-o-normal--18-*-*-*-m-*-iso8859-1"
 #define BoldFontDefault       "-adobe-courier-bold-r-normal--18-*-*-*-m-*-iso8859-1"
-#endif
 
 
 
@@ -571,4 +551,25 @@ typedef struct parameter_list_type {
     struct parameter_list_type *next;
 }              *ParameterList;
 
+extern char *gDatabasePath;
+
+extern int gBorderColor;
+
+extern GroupItem   *gTopOfGroupStack;
+
+extern short int    gDisplayRegion;
+extern int          gRegionOffset;
+
+extern Window gActiveWindow;
+extern int    gNeedIconName;
+
+extern int  gScrollbarWidth;
+
+/* the width and height for all windows in the title bar */
+extern int  twwidth, twheight;
+
+extern short int gInPaste;
+
+#define ucharp_to_charp(x) ((char *)x)
+
 #endif
