@@ -33,7 +33,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /****************************************************************
  *
- * initx.h:  HyperDoc X Window window initialization code
+ * initx.c:  HyperDoc X Window window initialization code
  *
  * Copyright The Numerical Algorithms Group Limited 1991, 1992, 1993.
  *
@@ -44,8 +44,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "fricas_c_macros.h"
 #include "debug.h"
 
-#include "initx.h"
-
 #include <unistd.h>
 #include <sys/signal.h>
 #include <setjmp.h>
@@ -53,16 +51,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <X11/Xresource.h>
 #include <X11/Xatom.h>
 
-#ifdef SUN4OS5platform
-extern int gethostname(char *, int );
-#endif
-
 #include "ht_icon"
 #include "extent.h"
-#include "group.h"
-#include "mem.h"
-#include "scrollbar.h"
-#include "titlebar.h"
+#include "hyper.h"
 
 #include "all_hyper_proto.H1"
 #include "util.H1"
@@ -173,11 +164,12 @@ initializeWindowSystem(void)
 /*  fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 1\n");*/
     mousebits = XCreateBitmapFromData(gXDisplay,
         RootWindow(gXDisplay, gXScreenNumber),
-        mouseBitmap_bits, mouseBitmap_width,mouseBitmap_height);
+        ucharp_to_charp(mouseBitmap_bits),
+        mouseBitmap_width,mouseBitmap_height);
 /* fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 2\n");*/
     mousemask = XCreateBitmapFromData(gXDisplay,
         RootWindow(gXDisplay, gXScreenNumber),
-        mouseMask_bits, mouseMask_width,mouseMask_height);
+        ucharp_to_charp(mouseMask_bits), mouseMask_width,mouseMask_height);
 /* fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 2\n");*/
     gActiveCursor = XCreatePixmapCursor(gXDisplay,
         mousebits, mousemask, &fg, &bg,
@@ -393,7 +385,8 @@ set_name_and_icon(void)
     XStoreName(gXDisplay, gWindow->fMainWindow, "HyperDoc");
 
     /* define and assign the pixmap for the icon */
-    icon_pixmap = XCreateBitmapFromData(gXDisplay, gWindow->fMainWindow, ht_icon_bits,
+    icon_pixmap = XCreateBitmapFromData(gXDisplay, gWindow->fMainWindow,
+                                        ucharp_to_charp(ht_icon_bits),
                                         ht_icon_width, ht_icon_height);
     wmhints.icon_pixmap = icon_pixmap;
     wmhints.flags = IconPixmapHint;
@@ -497,7 +490,7 @@ open_window(Window w)
 }
 
 /***
-  This routine gets and sets the size for a new window. If the w paramter
+  This routine gets and sets the size for a new window. If the w parameter
   is null, it means that this is the initial window. Thus the user
   preferences are checked. If this is not the first window, then the
   window w is used as a guidline, and the new window is placed on top of
@@ -1009,7 +1002,7 @@ is_it_850(XFontStruct *fontarg)
 /* return 1 if it is 850 */
 
     s = XGetAtomName(gXDisplay,(Atom)fontarg->properties[i].card32);
-    val = !( strcmp("850",s) * strcmp("ibm-850",s));
+    val = !( strcmp("850",s) && strcmp("ibm-850",s));
     XFree(s);
     return( val );
   }
