@@ -34,17 +34,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "debug.h"
 
 #include "parse.h"
-#include "parse-aux.h"
-#include "parse-paste.h"
 #include "parse-types.h"
 #include "lex.h"
-#include "mem.h"
+#include "hyper.h"
 #include "extent.h"
-#include "event.h"
-#include "display.h"
-#include "group.h"
-#include "scrollbar.h"
-#include "titlebar.h"
 
 #include "all_hyper_proto.H1"
 
@@ -186,7 +179,7 @@ format_page(UnloadedPage *ulpage)
 
     /*
      * In case of an error I will have to get at this page so I can free the
-     * waisted memory
+     * wasted memory
      */
     formatpage = page;
     page->type = Normal;
@@ -429,7 +422,7 @@ parse_HyperDoc(void)
             else {
                 /* Oops I had a problem parsing this puppy */
                 curr_node->type = Noop;
-                fprintf(stderr, "(HyperDoc) \\else found without macthing if?\n");
+                fprintf(stderr, "(HyperDoc) \\else found without matching if?\n");
                 longjmp(jmpbuf, 1);
                 fprintf(stderr, "(HyperDoc) Longjmp failed -- Exiting \n");
                 exit(-1);
