@@ -163,7 +163,7 @@ is_valid_socket(const Sock* s)
 
 /* Because a socket on Windows platform is a not just a simple file
    descriptor as it is in the Unix world, it is invalid to use
-   a socket identifier as argument for read(), or close, and
+   a socket identifier as argument for read(), or close(), or
    any other file descriptor function.  Furthermore, Windows
    requires cleanup.  */
 
@@ -805,15 +805,16 @@ remote_stdio(Sock *sock)
       return;
     }
     if (FD_ISSET(0, &rd)) {
-      fgets(buf,1024,stdin);
-      len = strlen(buf);
-      /*
-          gets(buf);
-          len = strlen(buf);
-          *(buf+len) = '\n';
-          *(buf+len+1) = '\0';
-      */
-      swrite(sock, buf, len, "writing to remote stdin");
+      len = read(0, buf, 1024);
+      if (len == -1) {
+        perror("read from stdin");
+        return;
+      }
+      if (len == 0) {
+        /* EOF (CTRL-D) received, ignore it for now */
+      } else {
+        swrite(sock, buf, len, "writing to remote stdin");
+      }
     }
     if (FD_ISSET(sock->socket, &rd)) {
       len = sread(sock, buf, 1024, "stdio");
@@ -850,9 +851,7 @@ void
 close_socket(fricas_socket socket_num, char *name)
 {
   fricas_close_socket(socket_num);
-#ifndef RTplatform
   unlink(name);
-#endif
 }
 
 int
@@ -883,9 +882,11 @@ open_server(char *server_name)
 
   init_socks();
 #ifndef HAVE_MSG_NOSIGNAL
+#ifndef HAVE_SO_NOSIGPIPE
 #ifdef SIGPIPE
   bsdSignal(SIGPIPE, sigpipe_handler,RestartSystemCalls);
 #endif
+#endif
 #endif
   if (make_server_name(name, server_name) == -1)
     return -2;
@@ -932,6 +933,11 @@ open_server(char *server_name)
       server[1].socket = 0;
       return -2;
     }
+#ifdef HAVE_SO_NOSIGPIPE
+    /* macOS doesn't have MSG_NOSIGNAL, so use SO_NOSIGPIPE instead */
+    int set = 1;
+    setsockopt(server[1].socket, SOL_SOCKET, SO_NOSIGPIPE, (void *)&set, sizeof(int));
+#endif
     FD_SET(server[1].socket, &socket_mask);
     FD_SET(server[1].socket, &server_mask);
     listen(server[1].socket, 5);
@@ -1110,47 +1116,3 @@ print_line(char *s)
   printf("%s\n", s);
 }
 
-
-typedef union {
-  double        f;
-  long          l[2];
-        } DoubleFloat;
-
-double
-plus_infinity(void )
-{
-  static int init = 0;
-  static DoubleFloat pinf;
-  if (! init) {
-    pinf.l[0] = 0x7ff00000;
-    pinf.l[1] = 0;
-    init = 1;
-  }
-  return pinf.f;
-}
-
-double
-minus_infinity(void)
-{
-  static int init = 0;
-  static DoubleFloat minf;
-  if (! init) {
-    minf.l[0] = 0xfff00000L;
-    minf.l[1] = 0;
-    init = 1;
-  }
-  return minf.f;
-}
-
-double
-NANQ(void)
-{
-  static int init = 0;
-  static DoubleFloat nanq;
-  if (! init) {
-    nanq.l[0] = 0x7ff80000L;
-    nanq.l[1] = 0;
-    init = 1;
-  }
-  return nanq.f;
-}
